#
# spec file for package Printrun
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           Printrun
Version:        2.0.0~rc7.1599393390.c451359
Release:        3.14
Summary:        RepRap printer interface and tools
License:        GPL-3.0-or-later
Group:          Productivity/Graphics/Convertors
URL:            http://www.pronterface.com/
Source0:        Printrun-%{version}.tar.xz

# Desktop files
Source1:        pronsole.desktop
Source2:        pronterface.desktop
Source3:        plater.desktop

BuildRequires:  python3-Cython
BuildRequires:  python3-pyserial
BuildRequires:  python3-setuptools
BuildRequires:  gettext
%if 0%{?suse_version}
BuildRequires:  fdupes
BuildRequires:  update-desktop-files
%endif
%if 0%{?fedora_version}
BuildRequires:  desktop-file-utils
%endif

Requires:       plater = %{version}-%{release}
Requires:       pronsole = %{version}-%{release}
Requires:       pronterface = %{version}-%{release}

%description
Printrun is a set of G-code sending applications for RepRap.
It consists of printcore (dumb G-code sender), pronsole (featured command line
G-code sender), pronterface (featured G-code sender with graphical user
interface), and a small collection of helpful scripts. Together with skeinforge
they form a pretty powerful softwarecombo. This package installs whole Printrun.

###############################################

%package        common
Summary:        Common files for Printrun
Group:          Productivity/Graphics/Convertors
Requires:       python3-numpy
Requires:       python3-pyglet
Requires:       python3-pyserial

%description    common
Printrun is a set of G-code sending applications for RepRap.
This package contains common files.

###############################################

%package     -n pronsole
Summary:        CLI interface for RepRap
Group:          Productivity/Graphics/Convertors
Requires:       %{name}-common = %{version}-%{release}
BuildArch:      noarch

%description -n pronsole
Pronsole is a featured command line G-code sender.
It controls the ReRap printer and integrates skeinforge.
It is a part of Printrun.

###############################################

%package     -n pronterface
Summary:        GUI interface for RepRap
Group:          Productivity/Graphics/Convertors
Requires:       python3-wxPython
Requires:       pronsole = %{version}-%{release}
BuildArch:      noarch

%description -n pronterface
Pronterface is a featured G-code sender with graphical user interface.
It controls the ReRap printer and integrates skeinforge.
It is a part of Printrun.

###############################################

%package     -n plater
Summary:        RepRap STL plater
Group:          Productivity/Graphics/Convertors
Requires:       %{name}-common = %{version}-%{release}
Requires:       python3-wxPython
BuildArch:      noarch

%description -n plater
Plater is a GUI tool to prepare printing plate from STL files for ReRap.
It is a part of Printrun.

###############################################


%prep
%setup -q

# use launchers for skeinforge
sed -i 's|python skeinforge/skeinforge_application/skeinforge.py|skeinforge|' pronsole.py
sed -i 's|python skeinforge/skeinforge_application/skeinforge_utilities/skeinforge_craft.py|skeinforge-craft|' pronsole.py

# fixup shebangs, /usr/bin/env python3 -> python3, and executable bits
sed -s -i -e '1 s@/usr/bin/env python3@/usr/bin/python3@' printrun/*py

%build
%python3_build

# rebuild locales
cd locale
for FILE in *
  do msgfmt $FILE/LC_MESSAGES/plater.po -o $FILE/LC_MESSAGES/plater.mo || echo plater not there
     msgfmt $FILE/LC_MESSAGES/pronterface.po -o $FILE/LC_MESSAGES/pronterface.mo || echo pronterface not there
done
cd ..

%install
%python3_install

# fixup executable bits
for f in %{buildroot}%{python3_sitearch}/printrun/*py; do
  sed -e '/\/usr\/bin\/python3/ Q 1 ; Q 0' $f || chmod 0755 $f
done

# desktop files
%if 0%{?suse_version}
mkdir -p "%buildroot/%_docdir/%name"
mkdir -p %{buildroot}%{_datadir}/applications
install -Dm644 %{SOURCE1} %{buildroot}/%{_datadir}/applications/pronsole.desktop
install -Dm644 %{SOURCE2} %{buildroot}/%{_datadir}/applications/pronterface.desktop
install -Dm644 %{SOURCE3} %{buildroot}/%{_datadir}/applications/plater.desktop

%suse_update_desktop_file -i %{buildroot}/%{_datadir}/applications/pronsole.desktop
%suse_update_desktop_file -i %{buildroot}/%{_datadir}/applications/pronterface.desktop
%suse_update_desktop_file -i %{buildroot}/%{_datadir}/applications/plater.desktop
%fdupes -s %{buildroot}%{python3_sitearch}/
%endif

%if 0%{?fedora_version}
desktop-file-install --dir=%{buildroot}%{_datadir}/applications %{SOURCE1}
desktop-file-install --dir=%{buildroot}%{_datadir}/applications %{SOURCE2}
desktop-file-install --dir=%{buildroot}%{_datadir}/applications %{SOURCE3}
%endif

%{find_lang} pronterface
%{find_lang} plater

%files
%doc README*
%license COPYING

%files common
%doc README*
%license COPYING
%{python3_sitearch}/*
%{_bindir}/printcore.*

%files -n pronsole
%{_bindir}/pronsole.*
%{_datadir}/pixmaps/pronsole.png
%{_datadir}/applications/pronsole.desktop
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/pronsole.appdata.xml

%files -n pronterface -f pronterface.lang
%{_bindir}/pronterface.*
%{_datadir}/pronterface
%{_datadir}/pixmaps/pronterface.png
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/pronterface.appdata.xml
%{_datadir}/applications/pronterface.desktop

%files -n plater -f plater.lang
%{_bindir}/plater.*
%{_datadir}/pixmaps/plater.png
%{_datadir}/applications/plater.desktop
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/plater.appdata.xml

%changelog
* Mon Feb  8 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Remove two remaining instances of python_module macro, pulling
  in python36-wxPython.
* Sun Jan 24 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build failures after backwards incompatible changes to
  python-rpm-macros.
* Fri Nov  6 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- update to 2.0.0rc7
  * New Features:
    + Live resizing of panels and many other UI improvements (#1073)
    + Render G2/G3 arcs in 3D view by interpolating them as line
    segments (#1092 and #1097)
    + Apply grid size settings to 3d view (#1093)
    + Visualize moves with laser/spindle active as extrusion (#1094)
    + Keyboard shortcuts for important UI elements (00a932e)
    + Keyboard jogging improvements (#1100)
  * Fixed Bugs
    + Do not expand setting spinners, combo boxes and dropdown
    lists (5d42c19)
    + Build wheels for Windows and manylinux1/2014 correctly (#1087)
    + Allow spaces between coordinate and value when parsing
    coordinates in gcode (#1090)
    + Fix G2/G3 arc rendering error and scaling in 2D view (#1091)
    + Correct index of appended command in gcoder (#1057)
    + Fix incorrect string comparisons using "is" (#1096)
    + Fix D-pad/keyboard jog movements (#1084)
    + Fix incorrect enabled state of controls on UI settings
    change (f02f4ef)
    + Fix command history traversal (9d5620f)
    + Fix toolbar shortcuts, blank jog, jog tab-out on
    Windows (1f0290b)
    + Fix lost messages from Marlin that contain the string
    "Count" (#1104)
    + Fix wheel install paths for locales and images (#1101)
- update to 2.0.0rc6
  * New Features:
    + Change the default background color to the theme one (#931)
    + Add setting for graph background color (#791)
    + Hide second extruder from graph if not present (#791)
    + Support for disabling Mate screensaver service (#979)
    + Armenian translation (#1042)
    + Don't print the M117 status msg to the console (#1081)
    + Packages installable by pip are available on PyPI (#921)
  * Fixed Bugs
    + Don't ask for exit confirmation on the console when asking
    in GUI (b48fe7b)
    + Preset for temperatures does not affect Selection on the
    main screen (#676)
    + Several Python 3 related followups, mostly in
    run_gcode_script
    + Issue connecting to a remote port (#1027)
    + Run "Final command" from settings when print is
    finished (#1014)
    + Fix a crash in wx at startup due to locale settings (#1015)
    + Only apply PARITY_ODD workaround where it's actually
    needed (#1017)
    + Do not attempt to read extra device name patterns on
    windows (#1040)
    + Several Linux packaging fixes
    + Removed error-causing wxPython horizontal alignment
    flags (#1052)
    + Rewrite deprecated Serial functions (#1017), pySerial >= 3
    is now needed
    + 3D Viewer color options don't update (#1054)
    + Settings change callbacks not called (#1063 and others)
- Drop upstream fix-file-load.patch
- Clean up specfile
* Tue Feb 11 2020 Adrian Schröter <adrian@suse.de>
- fix file load in pronsole
* Tue Oct 30 2018 Adrian Schröter <adrian@suse.de>
- fix dependency to python3 modules (esp. wxWidgets)
* Tue Jul 17 2018 stefan.bruens@rwth-aachen.de
- Spec file fixes/cleanup:
  * Use python3, python2 is no longer supported by Printrun
  * Add missing setuptools dependency
  * Remove %%defattr
  * Tag COPYING with %%license, and only package it in common subpackage
- Drop obsolete Printrun-pyglet12.patch
* Tue Apr 10 2018 adrian@suse.de
- update to 2.0.0rc5
- switch to python3
* Wed Jun 21 2017 adrian@suse.de
- use upstream version scheme
* Fri Jun  2 2017 adrian@suse.de
- update to current code
- hack around to get it building
* Tue Aug  6 2013 jw@suse.com
- fixed desktop Categories
  according to http://en.opensuse.org/openSUSE:Packaging_desktop_menu_categories#Graphics
- fixed specfile:
  * chosen a valid group, instead of an invalid one
  * added the default defattr() line, (which is still needed explicitly even after so many years)
  * fixed license syntax.
